@@ -36,10 +36,10 @@ class QNTPServer():
         self.username = None
         self.password = None
         if config:
-            self.logs = setup_logger(self.uuid, config)
+            self.logs = setup_logger(__class__.__name__, self.uuid, config)
             set_local_vars(self, config)
         else:
-            self.logs = setup_logger(self.uuid, None)
+            self.logs = setup_logger(__class__.__name__, self.uuid, None)
         self.ip = ip or self.ip or '0.0.0.0'
         self.port = port or self.port or 123
         self.username = username or self.username or 'test'
@@ -65,7 +65,7 @@ class QNTPServer():
                 mode = 'UnKnown'
                 success = False
                 unpacked = None
-                _q_s.logs.info({'server': 'ntp_server', 'action': 'connection', 'src_ip': addr[0], 'src_port': addr[1]})
+                _q_s.logs.info({'server': 'ntp_server', 'action': 'connection', 'dest_ip': addr[0], 'dest_port': addr[1]})
                 if len(data) == calcsize('!B B B b I I I Q Q Q Q'):
                     version = data[0] >> 3 & 0x7
                     mode = data[0] & 0x7
@@ -77,9 +77,9 @@ class QNTPServer():
                         success = True
 
                 if success:
-                    _q_s.logs.info({'server': 'ntp_server', 'action': 'query', 'status': 'success', 'src_ip': addr[0], 'src_port': addr[1], 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'version': version, 'mode': mode})
+                    _q_s.logs.info({'server': 'ntp_server', 'action': 'query', 'status': 'success', 'dest_ip': addr[0], 'dest_port': addr[1], 'src_ip': _q_s.ip, 'src_port': _q_s.port, 'version': version, 'mode': mode})
                 else:
-                    _q_s.logs.info({'server': 'ntp_server', 'action': 'query', 'status': 'fail', 'src_ip': addr[0], 'src_port': addr[1], 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'version': version, 'mode': mode})
+                    _q_s.logs.info({'server': 'ntp_server', 'action': 'query', 'status': 'fail', 'dest_ip': addr[0], 'dest_port': addr[1], 'src_ip': _q_s.ip, 'src_port': _q_s.port, 'version': version, 'mode': mode})
 
                 self.transport.loseConnection()
 
@@ -103,7 +103,7 @@ class QNTPServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info({'server': 'ntp_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port})
+            self.logs.info({'server': 'ntp_server', 'action': 'process', 'status': status, 'dest_ip': self.ip, 'dest_port': self.port})
 
             if status == 'success':
                 return True
