@@ -36,10 +36,10 @@ class QOracleServer():
         self.username = None
         self.password = None
         if config:
-            self.logs = setup_logger(self.uuid, config)
+            self.logs = setup_logger(__class__.__name__, self.uuid, config)
             set_local_vars(self, config)
         else:
-            self.logs = setup_logger(self.uuid, None)
+            self.logs = setup_logger(__class__.__name__, self.uuid, None)
         self.ip = ip or self.ip or '0.0.0.0'
         self.port = port or self.port or 1521
         self.username = username or self.username or 'test'
@@ -88,12 +88,12 @@ class QOracleServer():
                 return service_name, program, local_user
 
             def connectionMade(self):
-                _q_s.logs.info({'server': 'oracle_server', 'action': 'connection', 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port})
+                _q_s.logs.info({'server': 'oracle_server', 'action': 'connection', 'dest_ip': self.transport.getPeer().host, 'dest_port': self.transport.getPeer().port, 'src_ip': _q_s.ip, 'src_port': _q_s.port})
 
             def dataReceived(self, data):
                 service_name, program, local_user = self.parse_payload(data)
                 if service_name or program or local_user:
-                    _q_s.logs.info({'server': 'oracle_server', 'action': 'login', 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'local_user': local_user, 'program': program, 'service_name': service_name})
+                    _q_s.logs.info({'server': 'oracle_server', 'action': 'login', 'dest_ip': self.transport.getPeer().host, 'dest_port': self.transport.getPeer().port, 'src_ip': _q_s.ip, 'src_port': _q_s.port, 'local_user': local_user, 'program': program, 'service_name': service_name})
                 self.transport.write(self.refuse_payload())
                 self.transport.loseConnection()
 
@@ -119,7 +119,7 @@ class QOracleServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info({'server': 'oracle_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port})
+            self.logs.info({'server': 'oracle_server', 'action': 'process', 'status': status, 'dest_ip': self.ip, 'dest_port': self.port})
 
             if status == 'success':
                 return True
